@@ -6,6 +6,12 @@
 set -e
 export LANG=C.UTF-8
 
+# prefer GDC 10 over the default for now
+if [ "$DC" = "gdc" ];
+then
+  export DC="gdc-10"
+fi
+
 echo "D compiler: $DC"
 set -v
 $DC --version
